==> qownnotes-debug-25.1.0-1-x86_64.pkg.tar.zst: usr/src/debug/qownnotes/qownnotes-25.1.0/qrc_qownnotes.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.16
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/qownnotes/src/qownnotes-25.1.0/icons/qownnotes/index.theme
  0x0,0x0,0x0,0x81,
  0x5b,
  0x49,0x63,0x6f,0x6e,0x20,0x54,0x68,0x65,0x6d,0x65,0x5d,0xa,0x4e,0x61,0x6d,0x65,
  0x3d,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,0x65,0x73,0x20,0x54,0x68,0x65,0x6d,0x65,
  0xa,0x43,0x6f,0x6d,0x6d,0x65,0x6e,0x74,0x3d,0x49,0x63,0x6f,0x6e,0x20,0x54,0x68,
  0x65,0x6d,0x65,0x20,0x66,0x6f,0x72,0x20,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,0x65,
  0x73,0xa,0x49,0x6e,0x68,0x65,0x72,0x69,0x74,0x73,0x3d,0x62,0x72,0x65,0x65,0x7a,
  0x65,0x2d,0x71,0x6f,0x77,0x6e,0x6e,0x6f,0x74,0x65,0x73,0xa,0x44,0x69,0x72,0x65,
  0x63,0x74,0x6f,0x72,0x69,0x65,0x73,0x3d,0x31,0x36,0x78,0x31,0x36,0xa,0x20,0xa,
  0x5b,0x31,0x36,0x78,0x31,0x36,0x5d,0xa,0x53,0x69,0x7a,0x65,0x3d,0x31,0x36,0xa,
  
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // qownnotes
  0x0,0x9,
  0xe,0x55,0x9a,0x3,
  0x0,0x71,
  0x0,0x6f,0x0,0x77,0x0,0x6e,0x0,0x6e,0x0,0x6f,0x0,0x74,0x0,0x65,0x0,0x73,
    // index.theme
  0x0,0xb,
  0xb,0xba,0x81,0xb5,
  0x0,0x69,
  0x0,0x6e,0x0,0x64,0x0,0x65,0x0,0x78,0x0,0x2e,0x0,0x74,0x0,0x68,0x0,0x65,0x0,0x6d,0x0,0x65,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x94,0x1e,0x69,0x50,0xb0,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x94,0x1e,0x69,0x50,0xb0,
  // :/icons/qownnotes
  0x0,0x0,0x0,0x10,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x94,0x1e,0x69,0x50,0xb0,
  // :/icons/qownnotes/index.theme
  0x0,0x0,0x0,0x28,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x94,0x1e,0x69,0x50,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qownnotes)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qownnotes)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qownnotes)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qownnotes)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qownnotes)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qownnotes)(); }
   } dummy;
}

==> qownnotes-debug-25.1.2-1-x86_64.pkg.tar.zst: usr/src/debug/qownnotes/qownnotes-25.1.2/qrc_qownnotes.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.16
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/qownnotes/src/qownnotes-25.1.2/icons/qownnotes/index.theme
  0x0,0x0,0x0,0x81,
  0x5b,
  0x49,0x63,0x6f,0x6e,0x20,0x54,0x68,0x65,0x6d,0x65,0x5d,0xa,0x4e,0x61,0x6d,0x65,
  0x3d,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,0x65,0x73,0x20,0x54,0x68,0x65,0x6d,0x65,
  0xa,0x43,0x6f,0x6d,0x6d,0x65,0x6e,0x74,0x3d,0x49,0x63,0x6f,0x6e,0x20,0x54,0x68,
  0x65,0x6d,0x65,0x20,0x66,0x6f,0x72,0x20,0x51,0x4f,0x77,0x6e,0x4e,0x6f,0x74,0x65,
  0x73,0xa,0x49,0x6e,0x68,0x65,0x72,0x69,0x74,0x73,0x3d,0x62,0x72,0x65,0x65,0x7a,
  0x65,0x2d,0x71,0x6f,0x77,0x6e,0x6e,0x6f,0x74,0x65,0x73,0xa,0x44,0x69,0x72,0x65,
  0x63,0x74,0x6f,0x72,0x69,0x65,0x73,0x3d,0x31,0x36,0x78,0x31,0x36,0xa,0x20,0xa,
  0x5b,0x31,0x36,0x78,0x31,0x36,0x5d,0xa,0x53,0x69,0x7a,0x65,0x3d,0x31,0x36,0xa,
  
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // qownnotes
  0x0,0x9,
  0xe,0x55,0x9a,0x3,
  0x0,0x71,
  0x0,0x6f,0x0,0x77,0x0,0x6e,0x0,0x6e,0x0,0x6f,0x0,0x74,0x0,0x65,0x0,0x73,
    // index.theme
  0x0,0xb,
  0xb,0xba,0x81,0xb5,
  0x0,0x69,
  0x0,0x6e,0x0,0x64,0x0,0x65,0x0,0x78,0x0,0x2e,0x0,0x74,0x0,0x68,0x0,0x65,0x0,0x6d,0x0,0x65,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x94,0x28,0xb9,0xf4,0x98,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x94,0x28,0xb9,0xf4,0x98,
  // :/icons/qownnotes
  0x0,0x0,0x0,0x10,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x94,0x28,0xb9,0xf4,0x98,
  // :/icons/qownnotes/index.theme
  0x0,0x0,0x0,0x28,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x94,0x28,0xb9,0xf4,0x98,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qownnotes)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qownnotes)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qownnotes)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qownnotes)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qownnotes)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qownnotes)(); }
   } dummy;
}
